# FastASH
Fast Averaged Shifted Histograms

## help for packaging

script files are provided and based on this tutorial :
https://levelup.gitconnected.com/how-to-deploy-a-cython-package-to-pypi-8217a6581f09